============
Activity Log
============

This gives us something to actually update when we want to make changes to make
sure the commit hash changes for release tests.

Log
===

2020-06-17:
    Testing out the ensure-tox and ensure-pip infra changes.

2020-06-23:
    Exercising recent change to simplify twine-upload role.

2020-07-01:
    The test bugfix/3.1 branch has been created. This is a commit to have
    mainline changes so we can see what needs to be done to do a "stable"
    release off of this bugfix branch.
